import React, { useState, useCallback, useEffect } from 'react';
import ReactDOM from 'react-dom';
import { select, axisLeft, axisBottom, csv, arc, pie, scaleBand, scaleLinear, max, format} from 'd3';

const csvUrl =
  'https://gist.githubusercontent.com/RajeevMukhesh/f9029c98b54f5ab962e6dc1a69e733e0/raw/f8d1c2d2afa828f1b4058718c2ed2f4e805acdb1/Top10MostPaidCelebrities2020.csv'
const width = 960;
const height = 400;
const margin = { top: 10, right: 50, bottom: 0, left: 150 };



const App = () => {
  const [data, setData] = useState(null);

  useEffect(() => {
    const row = d => {
      d.count = +d['Pay'];
      return d;
    };
    csv(csvUrl, row).then(data => {
      setData(data.slice(0, 100));
    });
  }, []);

  if (!data) {
    return <pre>Loading...</pre>;
  }

  const innerHeight = height - margin.top - margin.bottom - 30;
  const innerWidth = width - margin.left - margin.right + 10;
 
  const yScale = scaleBand()
    .domain(data.map(d => d.Name))
    .range([0, innerHeight]);

  const xScale = scaleLinear()
    .domain([0, max(data, d => d.count)])
    .range([0, innerWidth]);
	
  return (
    <svg width={width} height={height}>
      <g transform={`translate(${margin.left},${margin.top})`}>
        {xScale.ticks().map(tickValue => (
          <g key={tickValue} transform={`translate(${xScale(tickValue)},0)`}>
            <line y2={innerHeight} stroke="red" />
            <text
              style={{ textAnchor: 'middle' }}
              dy=".70em"
              y={innerHeight + 3}
            >
              {tickValue}
            </text>
          </g>
        ))}
        {yScale.domain().map(tickValue => (
          <text
            key={tickValue}
            style={{ textAnchor: 'end' }}
            x={-3}
            dy=".32em"
            y={yScale(tickValue) + yScale.bandwidth() / 2}
          >
            {tickValue}
          </text>
        ))}
        {data.map(d => (
          <rect
            key={d.Name}
            x={0}
            y={yScale(d.Name)}
            width={xScale(d.count)}
            height={yScale.bandwidth()}
          />
        ))}
      </g>
    </svg>
  );
};
const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);